==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/ColorSettings/ts/ColorSettings_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>ColorSettings</name>
    <message>
        <location filename="../ColorSettings.js" line="+25"/>
        <source>Defaults for New Drawings</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Domyślne dla nowych rysunków</translatorcomment>
        <translation type="unfinished">Domyślne dla nowych rysunków</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Printing - Colors</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Drukowanie - Colors</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Printing</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Drukowanie...
Drukowanie
Drukowanie zakończone</translatorcomment>
        <translation type="unfinished">Drukowanie</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kolory
&amp;Dodaj do własnych kolorów</translatorcomment>
        <translation type="unfinished">Kolory</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Background color:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Kolor tła:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Color Mode</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Tryb koloru</translatorcomment>
        <translation type="unfinished">Tryb koloru</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Full color</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pełny kolor</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Grayscale</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Skala szarości
4 bitowa skala szarości
2 bitowa skala szarości</translatorcomment>
        <translation type="unfinished">Skala szarości</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Black / white</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Czarny / Biały
Przełącz tryb czarno-biały</translatorcomment>
        <translation type="unfinished">Czarny / Biały</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/DrawingPreferences/ColorSettings/ts/ColorSettings_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ColorSettings</name>
    <message>
        <location filename="../ColorSettings.js" line="+25"/>
        <source>Defaults for New Drawings</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Domyślne dla nowych rysunków</translatorcomment>
        <translation>Domyślne dla nowych rysunków</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Printing - Colors</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Drukowanie - Kolory</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Printing</source>
        <translatorcomment>--exact match--
--file: linguist_pl.ts--
Drukowanie...
Drukowanie
Drukowanie zakończone</translatorcomment>
        <translation>Drukowanie</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kolory
&amp;Dodaj do własnych kolorów</translatorcomment>
        <translation>Kolory</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Background color:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Kolor tła:</translation>
    </message>
    <message>
        <location line="+44"/>
        <source>Color Mode</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Tryb koloru</translatorcomment>
        <translation>Tryb koloru</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Full color</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Pełny zakres barw</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Grayscale</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Skala szarości
4 bitowa skala szarości
2 bitowa skala szarości</translatorcomment>
        <translation>Skala szarości</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Black / white</source>
        <translatorcomment>--ignored case--
--file: qcadguiqt_pl.ts--
Czarny / Biały
Przełącz tryb czarno-biały</translatorcomment>
        <translation>Czarny / biały</translation>
    </message>
</context>
</TS>
